meta — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- bin »

# meta

Utility functions and classes to start a new Camelot project, this could be the start of MetaCamelot

class `camelot.bin.meta.` `CreateNewProject`

  Action to create a new project, based on a form with options the user fills in.

class `camelot.bin.meta.` `MetaCamelotAdmin`

  ApplicationAdmin class to be used within meta camelot

class `camelot.bin.meta.` `MetaCamelotApplication`(application_admin)

  A Camelot application to build new Camelot projects.

class `camelot.bin.meta.` `MetaSettings`

  settings target to be used within MetaCamelot, when no real settings are available yet

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- bin »

Comments
blog comments powered by Disqus